@@ -32,6 +32,7 @@ func TestLoadIacFile(t *testing.T) {
 	table := []struct {
 		name     string
 		filePath string
+		options  map[string]interface{}
 		k8sV1    K8sV1
 		typeOnly bool
 		want     output.AllResourceConfigs
@@ -80,7 +81,7 @@ func TestLoadIacFile(t *testing.T) {
 
 	for _, tt := range table {
 		t.Run(tt.name, func(t *testing.T) {
-			_, gotErr := tt.k8sV1.LoadIacFile(tt.filePath)
+			_, gotErr := tt.k8sV1.LoadIacFile(tt.filePath, tt.options)
 			if !reflect.DeepEqual(gotErr, tt.wantErr) {
 				t.Errorf("unexpected error; gotErr: '%v', wantErr: '%v'", gotErr, tt.wantErr)
 			} else if tt.typeOnly && (reflect.TypeOf(gotErr)) != reflect.TypeOf(tt.wantErr) {
