@@ -25,6 +25,7 @@ import (
 // LoadIacDir starts traversing from the given rootDir and traverses through
 // all the descendant modules present to create an output list of all the
 // resources present in rootDir and descendant modules
-func (*TfV15) LoadIacDir(absRootDir string, nonRecursive bool) (allResourcesConfig output.AllResourceConfigs, err error) {
-	return commons.NewTerraformDirectoryLoader(absRootDir, nonRecursive).LoadIacDir()
+func (*TfV15) LoadIacDir(absRootDir string, options map[string]interface{}) (allResourcesConfig output.AllResourceConfigs, err error) {
+
+	return commons.NewTerraformDirectoryLoader(absRootDir, options).LoadIacDir()
 }
