@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2021 Accurics, Inc.
+    Copyright (C) 2020 Accurics, Inc.
 
 	Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
@@ -16,13 +16,10 @@
 
 package core
 
-import (
-	"github.com/accurics/terrascan/pkg/iac-providers/output"
-	"github.com/accurics/terrascan/pkg/utils"
-)
+import "github.com/accurics/terrascan/pkg/iac-providers/output"
 
 // Mapper defines the base API that each IaC provider mapper must implement.
 type Mapper interface {
 	// Map transforms the provider specific template to terrascan native format.
-	Map(doc *utils.IacDocument, params ...map[string]interface{}) (output.AllResourceConfigs, error)
+	Map(resource interface{}, params ...map[string]interface{}) ([]output.ResourceConfig, error)
 }
