@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2021 Accurics, Inc.
+    Copyright (C) 2020 Accurics, Inc.
 
 	Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
@@ -18,6 +18,7 @@ package mapper
 
 import (
 	"github.com/accurics/terrascan/pkg/mapper/core"
+	"github.com/accurics/terrascan/pkg/mapper/iac-providers/arm"
 	"github.com/accurics/terrascan/pkg/mapper/iac-providers/cft"
 )
 
@@ -26,6 +27,8 @@ func NewMapper(iacType string) core.Mapper {
 	switch iacType {
 	case "cft":
 		return cft.Mapper()
+	case "arm":
+		return arm.Mapper()
 	}
 	return nil
 }
