@@ -11,7 +11,7 @@ import (
 
 const violationTemplateForGH = `{
           "version": "2.1.0",
-          "$schema": "https://raw.githubusercontent.com/oasis-tcs/sarif-spec/master/Schemata/sarif-schema-2.1.0.json",
+          "$schema": "https://json.schemastore.org/sarif-2.1.0-rtm.5.json",
           "runs": [
             {
               "tool": {
